from easytracer.tracer import Span
from easytracer.tracer import Tracer
from easytracer.config import Config


class HttpHeaders:
    TRACE_ID = "x-tracer-traceid"
    SPAN_ID = "x-tracer-spanid"
    SERVICE_NAME = "x-tracer-servicename"


def inject(span, carrier: dict):
    carrier[HttpHeaders.TRACE_ID] = span.trace_id
    carrier[HttpHeaders.SPAN_ID] = span.span_id
    carrier[HttpHeaders.SERVICE_NAME] = span.service_name


def extract(headers: dict) -> Span:
    # TODO: check if headers exist

    return Span(
        service_name=headers.get(HttpHeaders.SERVICE_NAME),
        name="parsed",
        trace_id=headers.get(HttpHeaders.TRACE_ID),
        span_id=headers.get(HttpHeaders.SPAN_ID)
    )



#!/usr/bin/env python3

from setuptools import setup, find_packages

version = '0.1.8'

setup(
    name='easytracer',
    version=version,
    description="Easy Distributed Tracing",
    long_description="""Easy Distributed Tracing""",
    classifiers=[],
    keywords='easytracer',
    author='Oscar Eriksson',
    author_email='oscar.eriks@gmail.com',
    url='https://github.com/thenetcircle/easytracer',
    license='LICENSE',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests', 'backend']),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "arrow"
    ],
    test_requires=[
    ])



from easytracer.tracer import Tracer
from easytracer.config_keys import ConfigKeys


class Config:
    def __init__(self, service_name: str, config: dict):
        self.service_name = service_name
        self.logging = config.get(ConfigKeys.LOGGING, True)
        self.sampler = config.get(ConfigKeys.SAMPLER, dict()).get(ConfigKeys.PARAM, 1)
        self.config = config

    def init_tracer(self) -> Tracer:
        return Tracer(self.service_name, self.logging, self.sampler, self.config)
